cgexplore.molecular.SpindryConformer
====================================

.. currentmodule:: cgexplore.molecular

.. autoclass:: SpindryConformer
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~SpindryConformer.to_stk_molecule
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~SpindryConformer.supramolecule
      ~SpindryConformer.energy_decomposition
      ~SpindryConformer.conformer_id
      ~SpindryConformer.source
   
   